"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SmartlingFileTranslationsApi = void 0;
const form_data_1 = __importDefault(require("form-data"));
const base_1 = require("../base");
const response_body_type_1 = require("../base/enum/response-body-type");
class SmartlingFileTranslationsApi extends base_1.SmartlingBaseApi {
    constructor(smartlingApiBaseUrl, authApi, logger) {
        super(logger);
        this.authApi = authApi;
        this.entrypoint = `${smartlingApiBaseUrl}/file-translations-api/v2/accounts`;
    }
    uploadFile(accountUid, parameters) {
        return __awaiter(this, void 0, void 0, function* () {
            const formData = new form_data_1.default();
            const exported = parameters.export();
            const fileOptions = {};
            if (exported.fileName) {
                fileOptions.filename = exported.fileName;
            }
            if (exported.contentType) {
                fileOptions.contentType = exported.contentType;
            }
            formData.append("file", exported.file, fileOptions);
            formData.append("request", JSON.stringify(exported.request), {
                contentType: "application/json"
            });
            return yield this.makeRequest("post", `${this.entrypoint}/${accountUid}/files`, formData, false, SmartlingFileTranslationsApi.fixContentTypeHeaderCase(formData));
        });
    }
    translateFile(accountUid, fileUid, params) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.makeRequest("post", `${this.entrypoint}/${accountUid}/files/${fileUid}/mt`, JSON.stringify(params.export()));
        });
    }
    getTranslationProgress(accountUid, fileUid, mtUid) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.makeRequest("get", `${this.entrypoint}/${accountUid}/files/${fileUid}/mt/${mtUid}/status`);
        });
    }
    downloadTranslatedFile(accountUid, fileUid, mtUid, localeId) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.makeRequest("get", `${this.entrypoint}/${accountUid}/files/${fileUid}/mt/${mtUid}/locales/${localeId}/file`, null, true);
        });
    }
    downloadTranslatedFileWithMetadata(accountUid, fileUid, mtUid, localeId) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield SmartlingFileTranslationsApi.downloadResponseToTranslatedFileDto(yield this.makeRequest("get", `${this.entrypoint}/${accountUid}/files/${fileUid}/mt/${mtUid}/locales/${localeId}/file`, null, response_body_type_1.ResponseBodyType.RAW_RESPONSE));
        });
    }
    downloadTranslatedFiles(accountUid, fileUid, mtUid) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.makeRequest("get", `${this.entrypoint}/${accountUid}/files/${fileUid}/mt/${mtUid}/locales/all/file/zip`, null, response_body_type_1.ResponseBodyType.ARRAY_BUFFER);
        });
    }
    downloadTranslatedFilesWithMetadata(accountUid, fileUid, mtUid) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield SmartlingFileTranslationsApi.downloadResponseToTranslatedFileDto(yield this.makeRequest("get", `${this.entrypoint}/${accountUid}/files/${fileUid}/mt/${mtUid}/locales/all/file/zip`, null, response_body_type_1.ResponseBodyType.RAW_RESPONSE));
        });
    }
    cancelFileTranslation(accountUid, fileUid, mtUid) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.makeRequest("post", `${this.entrypoint}/${accountUid}/files/${fileUid}/mt/${mtUid}/cancel`);
        });
    }
    detectFileLanguage(accountUid, fileUid, params) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.makeRequest("post", `${this.entrypoint}/${accountUid}/files/${fileUid}/language-detection`, JSON.stringify(params === null || params === void 0 ? void 0 : params.export()));
        });
    }
    getLanguageDetectionProgress(accountUid, fileUid, languageDetectionUid) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.makeRequest("get", `${this.entrypoint}/${accountUid}/files/${fileUid}/language-detection/${languageDetectionUid}/status`);
        });
    }
    static fixContentTypeHeaderCase(form) {
        const headers = form.getHeaders();
        headers["Content-Type"] = headers["content-type"];
        delete headers["content-type"];
        return headers;
    }
    static downloadResponseToTranslatedFileDto(response) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            const contentType = (_a = response.headers.get("content-type")) !== null && _a !== void 0 ? _a : undefined;
            const contentDisposition = response.headers.get("content-disposition");
            let fileName;
            if (contentDisposition) {
                const fileNameMatch = contentDisposition.match(/filename="((?:[^"\\]|\\.)*)"/);
                if (fileNameMatch) {
                    fileName = fileNameMatch[1].replace(/\\"/g, "\"");
                }
            }
            return {
                fileContent: yield response.arrayBuffer(),
                fileName,
                contentType
            };
        });
    }
}
exports.SmartlingFileTranslationsApi = SmartlingFileTranslationsApi;
//# sourceMappingURL=index.js.map