import FormData from "form-data";
import { SmartlingBaseApi } from "../base/index";
import { SmartlingAuthApi } from "../auth/index";
import { Logger } from "../logger";
import { DownloadFileParameters } from "./params/download-file-parameters";
import { UploadFileParameters } from "./params/upload-file-parameters";
import { FileStatusForAllLocalesDto } from "./dto/file-status-for-all-locales-dto";
import { SmartlingListResponse } from "../http/smartling-list-response";
import { LastModifiedForLocale } from "./dto/last-modified-for-locale-dto";
import { UploadedFileDto } from "./dto/uploaded-file-dto";
import { FileStatusForProjectDto } from "./dto/file-status-for-project-dto";
import { DownloadFileAllTranslationsParameters } from "./params/download-file-all-translations-parameters";
import { RecentlyUploadedFilesParameters } from "./params/recently-uploaded-files";
import { ResponseBodyType } from "../base/enum/response-body-type";
export declare class SmartlingFilesApi extends SmartlingBaseApi {
    constructor(smartlingApiBaseUrl: string, authApi: SmartlingAuthApi, logger: Logger);
    getStatusForAllLocales(projectId: string, fileUri: string): Promise<FileStatusForAllLocalesDto>;
    getLastModified(projectId: string, fileUri: string): Promise<SmartlingListResponse<LastModifiedForLocale>>;
    downloadFile(projectId: string, fileUri: string, locale: string, params: DownloadFileParameters, responseType?: ResponseBodyType): Promise<string>;
    downloadFileAllTranslations(projectId: string, fileUri: string, params: DownloadFileAllTranslationsParameters): Promise<string>;
    deleteFile(projectId: string, fileUri: string): Promise<boolean>;
    uploadFile(projectId: string, parameters: UploadFileParameters): Promise<UploadedFileDto>;
    getRecentlyUploadedFiles(projectId: string, params: RecentlyUploadedFilesParameters): Promise<SmartlingListResponse<FileStatusForProjectDto>>;
    static fixContentTypeHeaderCase(form: FormData): Record<string, unknown>;
}
